==> segment-local-functions-0.1.0.tgz: package/src/settings.ts <==
// import * as path from 'path'
// import * as fs from 'fs'
// import { ServerArgs } from './server'
// import { ProtocolArgs } from './generate_protocol'
// // import { onRequest } from './src_fn'
// // import { onIdentify, onTrack, onAlias, onPage, onScreen } from './dest_fn'

export type SrcFn = (request: SegmentSourceRequest, settings: SegmentSettings) => void
export type DestFns = {
  onAlias?: (event: SegmentProcessedEvent<SegmentAliasEvent>, settings: SegmentSettings) => void
  onScreen?: (event: SegmentProcessedEvent<SegmentScreenEvent>, settings: SegmentSettings) => void
  onPage?: (event: SegmentProcessedEvent<SegmentPageEvent>, settings: SegmentSettings) => void
  onIdentify?: (event: SegmentProcessedEvent<SegmentIdentifyEvent>, settings: SegmentSettings) => void
  onTrack?: (event: SegmentProcessedEvent<SegmentTrackEvent>, settings: SegmentSettings) => void
  onGroup?: (event: SegmentProcessedEvent<SegmentGroupEvent>, settings: SegmentSettings) => void
}

// export type Settings = { server: ServerArgs, protocol: ProtocolArgs }

// export function load_settings_env(base_dir: string, src_fn?: SrcFn, dest_fn?: DestFns): Settings | undefined | number[] {
//   let p = path.join(base_dir, 'settings.env')
//   let error_lines: number[] = []
//   if (!fs.existsSync(p)) {
//     return
//   }
//   let s = fs.readFileSync(p, 'utf8')
//   s = s.replace('/\r/g', '')
//   let ss = s.split('\n')
//   let server = {} as ServerArgs
//   let protocol = {} as ProtocolArgs

//   if (src_fn) {
//     server.src_fn = src_fn
//   }
//   if (dest_fn) {
//     server.dest_fn = dest_fn
//   }
//   // {
//   //   identify_fn: onIdentify,
//   //   track_fn: onTrack,
//   //   alias_fn: onAlias,
//   //   page_fn: onPage,
//   //   screen_fn: onScreen
//   // }

//   //  = {
//   //   export_dir: process.cwd()
//   // }
//   ss.forEach((s, i) => {
//     let kv = s.split('=')
//     if (kv.length == 2) {
//       let key = kv[0].trim().toLowerCase()
//       let value = kv[1].trim()
//       switch (key) {
//         case 'src_dir': {
//           protocol.out_file = path.join(value, 'protocol.d.ts')
//           break
//         }
//         case 'tp_name': {
//           protocol.tp_name = value
//           break
//         }
//         case 'work_id': {
//           protocol.work_slug = value
//           break
//         }
//         case 'access_token': {
//           protocol.access_token = value
//           break
//         }
//         case 'access_token': {
//           server.access_token = value
//           break
//         }
//         case 'src_fn_name': {
//           protocol.src_fn_name = value
//           break
//         }
//         case 'dest_fn_name': {
//           protocol.dest_fn_name = value
//           break
//         }
//         // case 'is_src': {
//         //   break
//         // }
//         default: {
//           error_lines.push(i)
//         }
//       }
//       // if (key == 'export_dir') {
//       //   output.export_dir = path.isAbsolute(value) ? value : path.join(process.cwd(), value)
//       // } else if (key == 'port') {
//       //   let port = parseInt(value)
//       //   if (isNaN(port)) {
//       //     error_lines.push(i)
//       //   }
//       //   output.port = port
//       // }
//     } else {
//       error_lines.push(i)
//     }
//   })
//   return error_lines.length == 0 ? { server, protocol } : error_lines
// }

==> segment-local-functions-0.1.2.tgz: package/src/settings.ts <==
// import * as path from 'path'
// import * as fs from 'fs'
// import { ServerArgs } from './server'
// import { ProtocolArgs } from './generate_protocol'
// // import { onRequest } from './src_fn'
// // import { onIdentify, onTrack, onAlias, onPage, onScreen } from './dest_fn'
import YAML from 'yaml'
import * as fs from 'fs-extra'
import * as path from 'path'
import 'segment-typescript-definitions/common'
import 'segment-typescript-definitions/custom-source'
import 'segment-typescript-definitions/custom-destination'

export type SrcFn = (request: SegmentSourceRequest, settings: SegmentSettings) => void
export type DestFns = {
  onAlias?: (event: SegmentProcessedEvent<SegmentAliasEvent>, settings: SegmentSettings) => void
  onScreen?: (event: SegmentProcessedEvent<SegmentScreenEvent>, settings: SegmentSettings) => void
  onPage?: (event: SegmentProcessedEvent<SegmentPageEvent>, settings: SegmentSettings) => void
  onIdentify?: (event: SegmentProcessedEvent<SegmentIdentifyEvent>, settings: SegmentSettings) => void
  onTrack?: (event: SegmentProcessedEvent<SegmentTrackEvent>, settings: SegmentSettings) => void
  onGroup?: (event: SegmentProcessedEvent<SegmentGroupEvent>, settings: SegmentSettings) => void
}

export type Settings = {
  language: 'typescript' | 'javascript'
  fn_name: string
  fn_type: 'source' | 'destination'
  work_slug?: string
  work_id?: string
  access_token?: string
  access_token_is_saved?: boolean
  tp_name?: string
  debug_port: number
  sam_port: number
  proxy_port?: number
  use_ngrok?: boolean
  github_deployment?: boolean
  fn_id: string
  generate_tests: boolean
}

export function get_source_file(settings: Settings) {
  return path.join(process.cwd(), 'src', settings.language == 'javascript' ? 'function.js' : 'function.ts')
}

export function get_deploy_file(settings: Settings) {
  return path.join(process.cwd(), settings.language == 'javascript' ? 'src' : 'out', 'function.js')
}

export function get_settings_file(dir?: string) {
  return path.join(dir || process.cwd(), 'sloth.yaml')
}

export async function load_settings(file: string): Promise<Settings> {
  let f = await fs.readFile(file, 'utf8')
  return YAML.parse(f)
}

export async function save_settings(file: string, settings: Settings) {
  await fs.writeFile(file, YAML.stringify(settings), 'utf8')
}
// export type Settings = {
//   debug_port: number
//   sam_port: number
//   work_slug: number
//   work_id: number

//  }

// export function load_settings_env(base_dir: string, src_fn?: SrcFn, dest_fn?: DestFns): Settings | undefined | number[] {
//   let p = path.join(base_dir, 'settings.env')
//   let error_lines: number[] = []
//   if (!fs.existsSync(p)) {
//     return
//   }
//   let s = fs.readFileSync(p, 'utf8')
//   s = s.replace('/\r/g', '')
//   let ss = s.split('\n')
//   let server = {} as ServerArgs
//   let protocol = {} as ProtocolArgs

//   if (src_fn) {
//     server.src_fn = src_fn
//   }
//   if (dest_fn) {
//     server.dest_fn = dest_fn
//   }
//   // {
//   //   identify_fn: onIdentify,
//   //   track_fn: onTrack,
//   //   alias_fn: onAlias,
//   //   page_fn: onPage,
//   //   screen_fn: onScreen
//   // }

//   //  = {
//   //   export_dir: process.cwd()
//   // }
//   ss.forEach((s, i) => {
//     let kv = s.split('=')
//     if (kv.length == 2) {
//       let key = kv[0].trim().toLowerCase()
//       let value = kv[1].trim()
//       switch (key) {
//         case 'src_dir': {
//           protocol.out_file = path.join(value, 'protocol.d.ts')
//           break
//         }
//         case 'tp_name': {
//           protocol.tp_name = value
//           break
//         }
//         case 'work_id': {
//           protocol.work_slug = value
//           break
//         }
//         case 'access_token': {
//           protocol.access_token = value
//           break
//         }
//         case 'access_token': {
//           server.access_token = value
//           break
//         }
//         case 'src_fn_name': {
//           protocol.src_fn_name = value
//           break
//         }
//         case 'dest_fn_name': {
//           protocol.dest_fn_name = value
//           break
//         }
//         // case 'is_src': {
//         //   break
//         // }
//         default: {
//           error_lines.push(i)
//         }
//       }
//       // if (key == 'export_dir') {
//       //   output.export_dir = path.isAbsolute(value) ? value : path.join(process.cwd(), value)
//       // } else if (key == 'port') {
//       //   let port = parseInt(value)
//       //   if (isNaN(port)) {
//       //     error_lines.push(i)
//       //   }
//       //   output.port = port
//       // }
//     } else {
//       error_lines.push(i)
//     }
//   })
//   return error_lines.length == 0 ? { server, protocol } : error_lines
// }
